.. _geometry:

===============
Geometry module
===============

This module is a direct copy of the SENeC package
`PyNCulture <https://github.com/SENeC-Initiative/PyNCulture>`_.
Therefore, in the examples below, you will have to import ``nngt`` instead of
``PyNCulture`` and replace ``pnc`` by ``nngt.geometry``.


Overview
========

.. autosummary::

    nngt.geometry.Area
    nngt.geometry.Shape
    nngt.geometry.culture_from_file
    nngt.geometry.plot_shape
    nngt.geometry.pop_largest
    nngt.geometry.shapes_from_file


.. automodule:: nngt.geometry
